@@ -23,6 +23,14 @@ limitations under the License.
 
 import pkg_resources
 
+from .exceptions import (
+    ISYConnectionError,
+    ISYInvalidAuthError,
+    ISYMaxConnections,
+    ISYResponseParseError,
+    ISYStreamDataError,
+    ISYStreamDisconnected,
+)
 from .isy import ISY
 
 try:
@@ -30,7 +38,15 @@ try:
 except (pkg_resources.ResolutionError, pkg_resources.ExtractionError):
     __version__ = "unknown"
 
-__all__ = ["ISY"]
+__all__ = [
+    "ISY",
+    "ISYInvalidAuthError",
+    "ISYConnectionError",
+    "ISYMaxConnections",
+    "ISYResponseParseError",
+    "ISYStreamDataError",
+    "ISYStreamDisconnected",
+]
 __author__ = "Ryan M. Kraus"
 __email__ = "rmkraus at gmail dot com"
 __date__ = "February 2020"
