@@ -1,7 +1,6 @@
 """Constants for the PyISY Module."""
 import datetime
 import logging
-from xml.parsers.expat import ExpatError
 
 _LOGGER = logging.getLogger(__package__)
 LOG_LEVEL = logging.DEBUG
@@ -24,7 +23,7 @@ XML_FALSE = "false"
 XML_ON = "<on />"
 XML_OFF = "<off />"
 
-POLL_TIME = 5
+POLL_TIME = 10
 RECONNECT_DELAY = 60
 SOCKET_BUFFER_SIZE = 4096
 THREAD_SLEEP_TIME = 30.0
@@ -38,16 +37,25 @@ ES_INITIALIZING = "stream_initializing"
 ES_LOADED = "stream_loaded"
 ES_RECONNECT_FAILED = "reconnect_failed"
 ES_RECONNECTING = "reconnecting"
+ES_DISCONNECTING = "stream_disconnecting"
+ES_NOT_STARTED = "not_started"
 
 ISY_VALUE_UNKNOWN = -1 * float("inf")
 ISY_PROP_NOT_SET = "-1"
 
-XML_ERRORS = (AttributeError, KeyError, ValueError, TypeError, IndexError, ExpatError)
-XML_PARSE_ERROR = "ISY Could not parse response, poorly formatted XML."
-
 """ Dictionary of X10 commands. """
 X10_COMMANDS = {"all_off": 1, "all_on": 4, "on": 3, "off": 11, "bright": 7, "dim": 15}
 
+ACTION_EVENT_STATUS = "0"
+ACTION_GET_STATUS = "1"
+ACTION_KEY_CHANGED = "2"
+ACTION_INFO_STRING = "3"
+ACTION_IR_LEARN = "4"
+ACTION_SCHEDULE = "5"
+ACTION_VAR_STATUS = "6"
+ACTION_VAR_INIT = "7"
+ACTION_KEY = "8"
+
 ATTR_ACTION = "action"
 ATTR_CONTROL = "control"
 ATTR_DESC = "desc"
@@ -70,13 +78,18 @@ ATTR_VAL = "val"  # Used for Variables.
 ATTR_VALUE = "value"  # Used for everything else.
 ATTR_VAR = "var"
 
+DEFAULT_PRECISION = "0"
+DEFAULT_UNIT_OF_MEASURE = ""
+
 TAG_ADDRESS = "address"
 TAG_CATEGORY = "cat"
+TAG_CONFIG = "config"
 TAG_DESC = "desc"
 TAG_DESCRIPTION = "description"
 TAG_DEVICE_TYPE = "devtype"
 TAG_DST = "DST"
 TAG_ENABLED = "enabled"
+TAG_EVENT_INFO = "eventInfo"
 TAG_FAMILY = "family"
 TAG_FEATURE = "feature"
 TAG_FIRMWARE = "app_full_version"
@@ -98,6 +111,7 @@ TAG_NODE = "node"
 TAG_NODE_DEFS = "nodedefs"
 TAG_NTP = "NTP"
 TAG_PARENT = "parent"
+TAG_PARAMETER = "parameter"
 TAG_PRGM_FINISH = "f"
 TAG_PRGM_RUN = "r"
 TAG_PRGM_RUNNING = "running"
@@ -107,11 +121,13 @@ TAG_PRODUCT = "product"
 TAG_PROGRAM = "program"
 TAG_PROPERTY = "property"
 TAG_ROOT = "root"
+TAG_SIZE = "size"
 TAG_SPOKEN = "spoken"
 TAG_SUNRISE = "Sunrise"
 TAG_SUNSET = "Sunset"
 TAG_TYPE = "type"
 TAG_TZ_OFFSET = "TMZOffset"
+TAG_VALUE = "value"
 TAG_VARIABLE = "e"
 TAG_VARIABLES = "variables"
 
@@ -125,6 +141,18 @@ PROTO_STATE_VAR = "state_variable"
 PROTO_ZIGBEE = "zigbee"
 PROTO_ZWAVE = "zwave"
 
+FAMILY_CORE = "0"
+FAMILY_INSTEON = "1"
+FAMILY_UPB = "2"
+FAMILY_RCS = "3"
+FAMILY_ZWAVE = "4"
+FAMILY_AUTO = "5"
+FAMILY_GENERIC = "6"
+FAMILY_UDI = "7"
+FAMILY_BRULTECH = "8"
+FAMILY_NCD = "9"
+FAMILY_NODESERVER = "10"
+
 PROP_BATTERY_LEVEL = "BATLVL"
 PROP_BUSY = "BUSY"
 PROP_COMMS_ERROR = "ERR"
@@ -139,15 +167,19 @@ PROP_SETPOINT_HEAT = "CLISPH"
 PROP_STATUS = "ST"
 PROP_TEMPERATURE = "CLITEMP"
 PROP_UOM = "UOM"
+PROP_ZWAVE_PREFIX = "ZW_"
 
-METHOD_GET = "get"
 METHOD_COMMAND = "cmd"
+METHOD_GET = "get"
+METHOD_SET = "set"
 
+URL_CHANGE = "change"
 URL_CLOCK = "time"
 URL_CONFIG = "config"
 URL_DEFINITIONS = "definitions"
 URL_MEMBERS = "members"
 URL_NETWORK = "networking"
+URL_NODE = "node"
 URL_NODES = "nodes"
 URL_NOTES = "notes"
 URL_PING = "ping"
@@ -157,6 +189,7 @@ URL_RESOURCES = "resources"
 URL_STATUS = "status"
 URL_SUBFOLDERS = "subfolders"
 URL_VARIABLES = "vars"
+URL_ZWAVE = "zwave"
 
 VAR_INTEGER = "1"
 VAR_STATE = "2"
@@ -699,15 +732,14 @@ INSTEON_SUBNODE_DIMMABLE = " 1"
 ZWAVE_CAT_DIMMABLE = ["109", "119", "186"]
 
 # Insteon Battery Devices - States are ignored when checking the status of a group.
-INSTEON_STATELESS_TYPE = ["0.16.", "0.17.", "0.18.", "16."]  # Not Used
-INSTEON_STATELESS_NODEDEFID = [
+INSTEON_BATTERY_TYPE = ["0.16.", "0.17.", "0.18.", "16."]
+INSTEON_BATTERY_NODEDEFID = [
     "BinaryAlarm",
     "BinaryAlarm_ADV",
     "BinaryControl",
     "BinaryControl_ADV",
     "RemoteLinc2",
     "RemoteLinc2_ADV",
-    "DimmerSwitchOnly",
 ]
 
 # Referenced from ISY-WSDK 4_fam.xml
