@@ -1,5 +1,5 @@
 """ISY Network Resources Module."""
-from time import sleep
+from asyncio import sleep
 from xml.dom import minidom
 
 from .constants import (
@@ -7,12 +7,10 @@ from .constants import (
     ATTR_ID,
     TAG_NAME,
     TAG_NET_RULE,
-    THREAD_SLEEP_TIME,
     URL_NETWORK,
     URL_RESOURCES,
-    XML_ERRORS,
-    XML_PARSE_ERROR,
 )
+from .exceptions import XML_ERRORS, XML_PARSE_ERROR, ISYResponseParseError
 from .helpers import value_from_xml
 
 
@@ -67,37 +65,38 @@ class NetworkResources:
             xmldoc = minidom.parseString(xml)
         except XML_ERRORS:
             _LOGGER.error("%s: NetworkResources", XML_PARSE_ERROR)
-        else:
-            features = xmldoc.getElementsByTagName(TAG_NET_RULE)
-            for feature in features:
-                address = int(value_from_xml(feature, ATTR_ID))
-                if address not in self.addresses:
-                    nname = value_from_xml(feature, TAG_NAME)
-                    nobj = NetworkCommand(self, address)
-                    self.addresses.append(address)
-                    self.nnames.append(nname)
-                    self.nobjs.append(nobj)
+            raise ISYResponseParseError(XML_PARSE_ERROR)
 
-            _LOGGER.info("ISY Loaded Network Resources Commands")
+        features = xmldoc.getElementsByTagName(TAG_NET_RULE)
+        for feature in features:
+            address = int(value_from_xml(feature, ATTR_ID))
+            if address not in self.addresses:
+                nname = value_from_xml(feature, TAG_NAME)
+                nobj = NetworkCommand(self, address)
+                self.addresses.append(address)
+                self.nnames.append(nname)
+                self.nobjs.append(nobj)
 
-    def update(self, wait_time=0):
+        _LOGGER.info("ISY Loaded Network Resources Commands")
+
+    async def update(self, wait_time=0):
         """
         Update the contents of the networking class.
 
         wait_time: [optional] Amount of seconds to wait before updating
         """
-        sleep(wait_time)
-        xml = self.isy.conn.get_network()
+        await sleep(wait_time)
+        xml = await self.isy.conn.get_network()
         self.parse(xml)
 
-    def update_threaded(self):
+    async def update_threaded(self, interval):
         """
         Continually update the class until it is told to stop.
 
         Should be run in a thread.
         """
         while self.isy.auto_update:
-            self.update(THREAD_SLEEP_TIME)
+            await self.update(interval)
 
     def __getitem__(self, val):
         """Return the item from the collection."""
@@ -171,11 +170,11 @@ class NetworkCommand:
         """Return the Resource ID for the Network Resource."""
         return self._id
 
-    def run(self):
+    async def run(self):
         """Execute the networking command."""
         req_url = self.isy.conn.compile_url([URL_NETWORK, URL_RESOURCES, str(self._id)])
 
-        if not self.isy.conn.request(req_url, ok404=True):
+        if not await self.isy.conn.request(req_url, ok404=True):
             _LOGGER.warning("ISY could not run networking command: %s", str(self._id))
             return
         _LOGGER.debug("ISY ran networking command: %s", str(self._id))
