@@ -1,5 +1,5 @@
 """Representation of ISY Nodes."""
-from time import sleep
+from asyncio import sleep
 from xml.dom import minidom
 
 from ..constants import (
@@ -12,7 +12,13 @@ from ..constants import (
     ATTR_NODE_DEF_ID,
     ATTR_PRECISION,
     ATTR_UNIT_OF_MEASURE,
+    DEFAULT_PRECISION,
+    DEFAULT_UNIT_OF_MEASURE,
     EVENT_PROPS_IGNORED,
+    FAMILY_BRULTECH,
+    FAMILY_NODESERVER,
+    FAMILY_RCS,
+    FAMILY_ZWAVE,
     INSTEON_RAMP_RATES,
     ISY_VALUE_UNKNOWN,
     NC_NODE_ERROR,
@@ -38,10 +44,9 @@ from ..constants import (
     TAG_PRIMARY_NODE,
     TAG_TYPE,
     UOM_SECONDS,
-    XML_ERRORS,
-    XML_PARSE_ERROR,
     XML_TRUE,
 )
+from ..exceptions import XML_ERRORS, XML_PARSE_ERROR, ISYResponseParseError
 from ..helpers import (
     NodeProperty,
     ZWaveProperties,
@@ -204,8 +209,10 @@ class Nodes:
             return
         value = value_from_xml(xmldoc, ATTR_ACTION, "")
         value = int(value) if value != "" else ISY_VALUE_UNKNOWN
-        prec = attr_from_xml(xmldoc, ATTR_ACTION, ATTR_PRECISION, "0")
-        uom = attr_from_xml(xmldoc, ATTR_ACTION, ATTR_UNIT_OF_MEASURE, "")
+        prec = attr_from_xml(xmldoc, ATTR_ACTION, ATTR_PRECISION, DEFAULT_PRECISION)
+        uom = attr_from_xml(
+            xmldoc, ATTR_ACTION, ATTR_UNIT_OF_MEASURE, DEFAULT_UNIT_OF_MEASURE
+        )
         formatted = value_from_xml(xmldoc, TAG_FORMATTED)
 
         # Process the action and value if provided in event data.
@@ -240,8 +247,10 @@ class Nodes:
         node.update_last_update()
         value = value_from_xml(xmldoc, ATTR_ACTION, 0)
         value = int(value) if value != "" else ISY_VALUE_UNKNOWN
-        prec = attr_from_xml(xmldoc, ATTR_ACTION, ATTR_PRECISION, "0")
-        uom = attr_from_xml(xmldoc, ATTR_ACTION, ATTR_UNIT_OF_MEASURE, "")
+        prec = attr_from_xml(xmldoc, ATTR_ACTION, ATTR_PRECISION, DEFAULT_PRECISION)
+        uom = attr_from_xml(
+            xmldoc, ATTR_ACTION, ATTR_UNIT_OF_MEASURE, DEFAULT_UNIT_OF_MEASURE
+        )
         formatted = value_from_xml(xmldoc, TAG_FORMATTED)
 
         if cntrl == PROP_RAMP_RATE:
@@ -267,7 +276,7 @@ class Nodes:
             return
         node = value_from_xml(xmldoc, TAG_NODE)
         if action == NC_NODE_ERROR:
-            _LOGGER.warning("ISY Could not communicate with device: %s", node)
+            _LOGGER.error("ISY Could not communicate with device: %s", node)
         # FUTURE: Handle additional node change actions to force updates.
 
     def parse(self, xml):
@@ -280,7 +289,7 @@ class Nodes:
             xmldoc = minidom.parseString(xml)
         except XML_ERRORS:
             _LOGGER.error("%s: Nodes", XML_PARSE_ERROR)
-            return False
+            raise ISYResponseParseError(XML_PARSE_ERROR)
 
         # get nodes
         ntypes = [TAG_FOLDER, TAG_NODE, TAG_GROUP]
@@ -303,14 +312,14 @@ class Nodes:
                 zwave_props = None
                 node_server = None
                 if family is not None:
-                    if family == "4":
+                    if family == FAMILY_ZWAVE:
                         protocol = PROTO_ZWAVE
                         zwave_props = ZWaveProperties(
                             feature.getElementsByTagName(TAG_DEVICE_TYPE)[0]
                         )
-                    elif family in ("3", "8"):
+                    elif family in (FAMILY_BRULTECH, FAMILY_RCS):
                         protocol = PROTO_ZIGBEE
-                    elif family == "10":
+                    elif family == FAMILY_NODESERVER:
                         # Node Server Slot is stored with family as text:
                         node_server = attr_from_xml(feature, TAG_FAMILY, ATTR_INSTANCE)
                         if node_server:
@@ -381,7 +390,7 @@ class Nodes:
                     )
             _LOGGER.debug("ISY Loaded %s", ntype)
 
-    def update(self, wait_time=0):
+    async def update(self, wait_time=0, xml=None):
         """
         Update the status and properties of the nodes in the class.
 
@@ -390,8 +399,10 @@ class Nodes:
         |  wait_time: [optional] Amount of seconds to wait before updating
         """
         if wait_time:
-            sleep(wait_time)
-        xml = self.isy.conn.get_status()
+            await sleep(wait_time)
+
+        if xml is None:
+            xml = await self.isy.conn.get_status()
 
         if xml is None:
             _LOGGER.warning("ISY Failed to update nodes.")
@@ -407,12 +418,12 @@ class Nodes:
             address = feature.attributes[ATTR_ID].value
 
             if address in self.addresses:
-                self.get_by_id(address).update(xmldoc=feature)
+                await self.get_by_id(address).update(xmldoc=feature)
                 continue
 
         _LOGGER.info("ISY Updated Node Statuses.")
 
-    def update_nodes(self, wait_time=0):
+    async def update_nodes(self, wait_time=0):
         """
         Update the contents of the class.
 
@@ -421,8 +432,8 @@ class Nodes:
         |  wait_time: [optional] Amount of seconds to wait before updating
         """
         if wait_time:
-            sleep(wait_time)
-        xml = self.isy.conn.get_nodes()
+            await sleep(wait_time)
+        xml = await self.isy.conn.get_nodes()
         if xml is None:
             _LOGGER.warning("ISY Failed to update nodes.")
             return
