@@ -1,5 +1,5 @@
 """ISY Variables."""
-from time import sleep
+from asyncio import sleep
 from xml.dom import minidom
 
 from dateutil import parser
@@ -15,9 +15,8 @@ from ..constants import (
     TAG_NAME,
     TAG_TYPE,
     TAG_VARIABLE,
-    XML_ERRORS,
-    XML_PARSE_ERROR,
 )
+from ..exceptions import XML_ERRORS, XML_PARSE_ERROR, ISYResponseParseError
 from ..helpers import attr_from_element, attr_from_xml, now, value_from_xml
 from .variable import Variable
 
@@ -115,7 +114,7 @@ class Variables:
             xmldoc = minidom.parseString(xml)
         except XML_ERRORS:
             _LOGGER.error("%s: Variables", XML_PARSE_ERROR)
-            return
+            raise ISYResponseParseError(XML_PARSE_ERROR)
 
         features = xmldoc.getElementsByTagName(ATTR_VAR)
         for feature in features:
@@ -141,14 +140,14 @@ class Variables:
 
         _LOGGER.info("ISY Loaded Variables")
 
-    def update(self, wait_time=0):
+    async def update(self, wait_time=0):
         """
         Update the variable objects with data from the controller.
 
         |  wait_time: Seconds to wait before updating.
         """
-        sleep(wait_time)
-        xml = self.isy.conn.get_variables()
+        await sleep(wait_time)
+        xml = await self.isy.conn.get_variables()
         if xml is not None:
             self.parse(xml)
         else:
